scoretools.PerformerInventory
=============================

.. abjad-lineage:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory

.. autoclass:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.append
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.count
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.extend
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.index
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.insert
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.item_class
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.name
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.new
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.pop
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.remove
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.reverse
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.sort
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.storage_format
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__contains__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delitem__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__eq__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getitem__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iadd__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iter__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__len__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ne__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__repr__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__reversed__
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setitem__

Bases
-----

- :py:class:`datastructuretools.TypedList <abjad.tools.datastructuretools.TypedList.TypedList.TypedList>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.item_class
   :noindex:

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.append
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.count
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.index
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.new
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setitem__
   :noindex:
